// python wrapper for vtkGeoView2D
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkGeoView2D.h"

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkGeoView2D(PyObject *); }
extern "C" { VTK_ABI_EXPORT PyObject *PyvtkGeoView2D_ClassNew(); }

#ifndef DECLARED_PyvtkRenderView_ClassNew
extern "C" { PyObject *PyvtkRenderView_ClassNew(); }
#define DECLARED_PyvtkRenderView_ClassNew
#endif

static const char *PyvtkGeoView2D_Doc =
  "vtkGeoView2D - A 2D geospatial view.\n\n"
  "Superclass: vtkRenderView\n\n"
  "vtkGeoView is a 2D globe view. The globe may contain a\n"
  "multi-resolution geometry source (vtkGeoTerrain2D), multiple\n"
  "multi-resolution image sources (vtkGeoAlignedImageRepresentation), as\n"
  "well as other representations such as vtkGeoGraphRepresentation2D. At\n"
  "a minimum, the view must have a terrain and one image representation.\n"
  "By default, you may select in the view with the left mouse button,\n"
  "pan with the middle button, and zoom with the right mouse button or\n"
  "scroll wheel.\n\n"
  "Each terrain or image representation contains a vtkGeoSource subclass\n"
  "which generates geometry or imagery at multiple resolutions. As the\n"
  "camera position changes, the terrain and/or image representations may\n"
  "ask its vtkGeoSource to refine the geometry. This refinement is\n"
  "performed on a separate thread, and the data is added to the view\n"
  "when it becomes available.\n\n"
  "@sa\n"
  "vtkGeoTerrain2D vtkGeoAlignedImageRepresentation vtkGeoSource\n\n";


static PyObject *
PyvtkGeoView2D_IsTypeOf(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkGeoView2D::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView2D_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView2D *op = static_cast<vtkGeoView2D *>(vp);

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkGeoView2D::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView2D_SafeDownCast(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkGeoView2D *tempr = vtkGeoView2D::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView2D_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView2D *op = static_cast<vtkGeoView2D *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkGeoView2D *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkGeoView2D::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView2D_GetSurface(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetSurface");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView2D *op = static_cast<vtkGeoView2D *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkGeoTerrain2D *tempr = (ap.IsBound() ?
      op->GetSurface() :
      op->vtkGeoView2D::GetSurface());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView2D_SetSurface(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetSurface");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView2D *op = static_cast<vtkGeoView2D *>(vp);

  vtkGeoTerrain2D *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkGeoTerrain2D"))
  {
    if (ap.IsBound())
    {
      op->SetSurface(temp0);
    }
    else
    {
      op->vtkGeoView2D::SetSurface(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView2D_GetTransform(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetTransform");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView2D *op = static_cast<vtkGeoView2D *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkAbstractTransform *tempr = (ap.IsBound() ?
      op->GetTransform() :
      op->vtkGeoView2D::GetTransform());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView2D_ApplyViewTheme(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ApplyViewTheme");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView2D *op = static_cast<vtkGeoView2D *>(vp);

  vtkViewTheme *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkViewTheme"))
  {
    if (ap.IsBound())
    {
      op->ApplyViewTheme(temp0);
    }
    else
    {
      op->vtkGeoView2D::ApplyViewTheme(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGeoView2D_Render(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "Render");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGeoView2D *op = static_cast<vtkGeoView2D *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->Render();
    }
    else
    {
      op->vtkGeoView2D::Render();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyMethodDef PyvtkGeoView2D_Methods[] = {
  {"IsTypeOf", PyvtkGeoView2D_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkGeoView2D_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkGeoView2D_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkGeoView2D\nC++: static vtkGeoView2D *SafeDownCast(vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkGeoView2D_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkGeoView2D\nC++: vtkGeoView2D *NewInstance()\n\n"},
  {"GetSurface", PyvtkGeoView2D_GetSurface, METH_VARARGS,
   "V.GetSurface() -> vtkGeoTerrain2D\nC++: virtual vtkGeoTerrain2D *GetSurface()\n\n"},
  {"SetSurface", PyvtkGeoView2D_SetSurface, METH_VARARGS,
   "V.SetSurface(vtkGeoTerrain2D)\nC++: virtual void SetSurface(vtkGeoTerrain2D *surf)\n\n"},
  {"GetTransform", PyvtkGeoView2D_GetTransform, METH_VARARGS,
   "V.GetTransform() -> vtkAbstractTransform\nC++: vtkAbstractTransform *GetTransform() override;\n\nReturns the transform associated with the surface.\n"},
  {"ApplyViewTheme", PyvtkGeoView2D_ApplyViewTheme, METH_VARARGS,
   "V.ApplyViewTheme(vtkViewTheme)\nC++: void ApplyViewTheme(vtkViewTheme *theme) override;\n\nApply the view theme to this view.\n"},
  {"Render", PyvtkGeoView2D_Render, METH_VARARGS,
   "V.Render()\nC++: void Render() override;\n\nUpdate and render the view.\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkGeoView2D_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  "vtkViewsGeovisPython.vtkGeoView2D", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
  nullptr, // tp_print
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkGeoView2D_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkGeoView2D_StaticNew()
{
  return vtkGeoView2D::New();
}

PyObject *PyvtkGeoView2D_ClassNew()
{
  PyVTKClass_Add(
    &PyvtkGeoView2D_Type, PyvtkGeoView2D_Methods,
    "vtkGeoView2D",
 &PyvtkGeoView2D_StaticNew);

  PyTypeObject *pytype = &PyvtkGeoView2D_Type;

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkRenderView_ClassNew();

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkGeoView2D(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkGeoView2D_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkGeoView2D", o) != 0)
  {
    Py_DECREF(o);
  }

}

