// python wrapper for vtkQtTreeRingLabelMapper
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkQtTreeRingLabelMapper.h"

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkQtTreeRingLabelMapper(PyObject *); }
extern "C" { VTK_ABI_EXPORT PyObject *PyvtkQtTreeRingLabelMapper_ClassNew(); }

#ifndef DECLARED_PyvtkLabeledDataMapper_ClassNew
extern "C" { PyObject *PyvtkLabeledDataMapper_ClassNew(); }
#define DECLARED_PyvtkLabeledDataMapper_ClassNew
#endif

static const char *PyvtkQtTreeRingLabelMapper_Doc =
  "vtkQtTreeRingLabelMapper - draw text labels on a tree map\n\n"
  "Superclass: vtkLabeledDataMapper\n\n"
  "vtkQtTreeRingLabelMapper is a mapper that renders text on a tree map.\n"
  "A tree map is a vtkTree with an associated 4-tuple array used for\n"
  "storing the boundary rectangle for each vertex in the tree. The user\n"
  "must specify the array name used for storing the rectangles.\n\n"
  "The mapper iterates through the tree and attempts and renders a label\n"
  "inside the vertex's rectangle as long as the following conditions\n"
  "hold:\n"
  "1. The vertex level is within the range of levels specified for\n"
  "   labeling.\n"
  "2. The label can fully fit inside its box.\n"
  "3. The label does not overlap an ancestor's label.\n\n"
  "@sa\n"
  "vtkLabeledDataMapper\n\n"
  "@par Thanks: Thanks to Jason Shepherd from Sandia National\n"
  "Laboratories for help in developing this class.\n\n";


static PyObject *
PyvtkQtTreeRingLabelMapper_IsTypeOf(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkQtTreeRingLabelMapper::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQtTreeRingLabelMapper_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQtTreeRingLabelMapper *op = static_cast<vtkQtTreeRingLabelMapper *>(vp);

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkQtTreeRingLabelMapper::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQtTreeRingLabelMapper_SafeDownCast(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkQtTreeRingLabelMapper *tempr = vtkQtTreeRingLabelMapper::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQtTreeRingLabelMapper_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQtTreeRingLabelMapper *op = static_cast<vtkQtTreeRingLabelMapper *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkQtTreeRingLabelMapper *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkQtTreeRingLabelMapper::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkQtTreeRingLabelMapper_RenderOpaqueGeometry(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "RenderOpaqueGeometry");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQtTreeRingLabelMapper *op = static_cast<vtkQtTreeRingLabelMapper *>(vp);

  vtkViewport *temp0 = nullptr;
  vtkActor2D *temp1 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetVTKObject(temp0, "vtkViewport") &&
      ap.GetVTKObject(temp1, "vtkActor2D"))
  {
    if (ap.IsBound())
    {
      op->RenderOpaqueGeometry(temp0, temp1);
    }
    else
    {
      op->vtkQtTreeRingLabelMapper::RenderOpaqueGeometry(temp0, temp1);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkQtTreeRingLabelMapper_RenderOverlay(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "RenderOverlay");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQtTreeRingLabelMapper *op = static_cast<vtkQtTreeRingLabelMapper *>(vp);

  vtkViewport *temp0 = nullptr;
  vtkActor2D *temp1 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetVTKObject(temp0, "vtkViewport") &&
      ap.GetVTKObject(temp1, "vtkActor2D"))
  {
    if (ap.IsBound())
    {
      op->RenderOverlay(temp0, temp1);
    }
    else
    {
      op->vtkQtTreeRingLabelMapper::RenderOverlay(temp0, temp1);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkQtTreeRingLabelMapper_GetInputTree(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetInputTree");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQtTreeRingLabelMapper *op = static_cast<vtkQtTreeRingLabelMapper *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkTree *tempr = (ap.IsBound() ?
      op->GetInputTree() :
      op->vtkQtTreeRingLabelMapper::GetInputTree());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQtTreeRingLabelMapper_SetSectorsArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetSectorsArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQtTreeRingLabelMapper *op = static_cast<vtkQtTreeRingLabelMapper *>(vp);

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetSectorsArrayName(temp0);
    }
    else
    {
      op->vtkQtTreeRingLabelMapper::SetSectorsArrayName(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkQtTreeRingLabelMapper_SetLabelTextProperty_s1(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetLabelTextProperty");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQtTreeRingLabelMapper *op = static_cast<vtkQtTreeRingLabelMapper *>(vp);

  vtkTextProperty *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkTextProperty"))
  {
    if (ap.IsBound())
    {
      op->SetLabelTextProperty(temp0);
    }
    else
    {
      op->vtkQtTreeRingLabelMapper::SetLabelTextProperty(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyObject *
PyvtkQtTreeRingLabelMapper_SetLabelTextProperty_s2(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetLabelTextProperty");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQtTreeRingLabelMapper *op = static_cast<vtkQtTreeRingLabelMapper *>(vp);

  vtkTextProperty *temp0 = nullptr;
  int temp1;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetVTKObject(temp0, "vtkTextProperty") &&
      ap.GetValue(temp1))
  {
    if (ap.IsBound())
    {
      op->SetLabelTextProperty(temp0, temp1);
    }
    else
    {
      op->vtkQtTreeRingLabelMapper::SetLabelTextProperty(temp0, temp1);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyObject *
PyvtkQtTreeRingLabelMapper_SetLabelTextProperty(PyObject *self, PyObject *args)
{
  int nargs = vtkPythonArgs::GetArgCount(self, args);

  switch(nargs)
  {
    case 1:
      return PyvtkQtTreeRingLabelMapper_SetLabelTextProperty_s1(self, args);
    case 2:
      return PyvtkQtTreeRingLabelMapper_SetLabelTextProperty_s2(self, args);
  }

  vtkPythonArgs::ArgCountError(nargs, "SetLabelTextProperty");
  return nullptr;
}



static PyObject *
PyvtkQtTreeRingLabelMapper_GetLabelTextProperty_s1(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetLabelTextProperty");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQtTreeRingLabelMapper *op = static_cast<vtkQtTreeRingLabelMapper *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkTextProperty *tempr = (ap.IsBound() ?
      op->GetLabelTextProperty() :
      op->vtkQtTreeRingLabelMapper::GetLabelTextProperty());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}

static PyObject *
PyvtkQtTreeRingLabelMapper_GetLabelTextProperty_s2(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetLabelTextProperty");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQtTreeRingLabelMapper *op = static_cast<vtkQtTreeRingLabelMapper *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    vtkTextProperty *tempr = (ap.IsBound() ?
      op->GetLabelTextProperty(temp0) :
      op->vtkQtTreeRingLabelMapper::GetLabelTextProperty(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}

static PyObject *
PyvtkQtTreeRingLabelMapper_GetLabelTextProperty(PyObject *self, PyObject *args)
{
  int nargs = vtkPythonArgs::GetArgCount(self, args);

  switch(nargs)
  {
    case 0:
      return PyvtkQtTreeRingLabelMapper_GetLabelTextProperty_s1(self, args);
    case 1:
      return PyvtkQtTreeRingLabelMapper_GetLabelTextProperty_s2(self, args);
  }

  vtkPythonArgs::ArgCountError(nargs, "GetLabelTextProperty");
  return nullptr;
}



static PyObject *
PyvtkQtTreeRingLabelMapper_SetTextRotationArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetTextRotationArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQtTreeRingLabelMapper *op = static_cast<vtkQtTreeRingLabelMapper *>(vp);

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetTextRotationArrayName(temp0);
    }
    else
    {
      op->vtkQtTreeRingLabelMapper::SetTextRotationArrayName(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkQtTreeRingLabelMapper_GetTextRotationArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetTextRotationArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQtTreeRingLabelMapper *op = static_cast<vtkQtTreeRingLabelMapper *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    char *tempr = (ap.IsBound() ?
      op->GetTextRotationArrayName() :
      op->vtkQtTreeRingLabelMapper::GetTextRotationArrayName());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQtTreeRingLabelMapper_GetMTime(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetMTime");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQtTreeRingLabelMapper *op = static_cast<vtkQtTreeRingLabelMapper *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    unsigned long tempr = (ap.IsBound() ?
      op->GetMTime() :
      op->vtkQtTreeRingLabelMapper::GetMTime());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQtTreeRingLabelMapper_SetRenderer(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetRenderer");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQtTreeRingLabelMapper *op = static_cast<vtkQtTreeRingLabelMapper *>(vp);

  vtkRenderer *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkRenderer"))
  {
    if (ap.IsBound())
    {
      op->SetRenderer(temp0);
    }
    else
    {
      op->vtkQtTreeRingLabelMapper::SetRenderer(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkQtTreeRingLabelMapper_GetRenderer(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetRenderer");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQtTreeRingLabelMapper *op = static_cast<vtkQtTreeRingLabelMapper *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkRenderer *tempr = (ap.IsBound() ?
      op->GetRenderer() :
      op->vtkQtTreeRingLabelMapper::GetRenderer());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}

static PyMethodDef PyvtkQtTreeRingLabelMapper_Methods[] = {
  {"IsTypeOf", PyvtkQtTreeRingLabelMapper_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkQtTreeRingLabelMapper_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkQtTreeRingLabelMapper_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkQtTreeRingLabelMapper\nC++: static vtkQtTreeRingLabelMapper *SafeDownCast(\n    vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkQtTreeRingLabelMapper_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkQtTreeRingLabelMapper\nC++: vtkQtTreeRingLabelMapper *NewInstance()\n\n"},
  {"RenderOpaqueGeometry", PyvtkQtTreeRingLabelMapper_RenderOpaqueGeometry, METH_VARARGS,
   "V.RenderOpaqueGeometry(vtkViewport, vtkActor2D)\nC++: void RenderOpaqueGeometry(vtkViewport *viewport,\n    vtkActor2D *actor) override;\n\nDraw the text to the screen at each input point.\n"},
  {"RenderOverlay", PyvtkQtTreeRingLabelMapper_RenderOverlay, METH_VARARGS,
   "V.RenderOverlay(vtkViewport, vtkActor2D)\nC++: void RenderOverlay(vtkViewport *viewport, vtkActor2D *actor)\n    override;\n\nDraw the text to the screen at each input point.\n"},
  {"GetInputTree", PyvtkQtTreeRingLabelMapper_GetInputTree, METH_VARARGS,
   "V.GetInputTree() -> vtkTree\nC++: virtual vtkTree *GetInputTree()\n\nThe input to this filter.\n"},
  {"SetSectorsArrayName", PyvtkQtTreeRingLabelMapper_SetSectorsArrayName, METH_VARARGS,
   "V.SetSectorsArrayName(string)\nC++: virtual void SetSectorsArrayName(const char *name)\n\nThe name of the 4-tuple array used for\n"},
  {"SetLabelTextProperty", PyvtkQtTreeRingLabelMapper_SetLabelTextProperty, METH_VARARGS,
   "V.SetLabelTextProperty(vtkTextProperty)\nC++: void SetLabelTextProperty(vtkTextProperty *p) override;\nV.SetLabelTextProperty(vtkTextProperty, int)\nC++: void SetLabelTextProperty(vtkTextProperty *p, int type)\n    override;\n\nSet/Get the text property. Note that multiple type text\nproperties (set with a second integer parameter) are not\ncurrently supported, but are provided to avoid compiler warnings.\n"},
  {"GetLabelTextProperty", PyvtkQtTreeRingLabelMapper_GetLabelTextProperty, METH_VARARGS,
   "V.GetLabelTextProperty() -> vtkTextProperty\nC++: vtkTextProperty *GetLabelTextProperty() override;\nV.GetLabelTextProperty(int) -> vtkTextProperty\nC++: vtkTextProperty *GetLabelTextProperty(int type) override;\n\nSet/Get the text property. Note that multiple type text\nproperties (set with a second integer parameter) are not\ncurrently supported, but are provided to avoid compiler warnings.\n"},
  {"SetTextRotationArrayName", PyvtkQtTreeRingLabelMapper_SetTextRotationArrayName, METH_VARARGS,
   "V.SetTextRotationArrayName(string)\nC++: virtual void SetTextRotationArrayName(const char *_arg)\n\nSet/Get the name of the text rotation array.\n"},
  {"GetTextRotationArrayName", PyvtkQtTreeRingLabelMapper_GetTextRotationArrayName, METH_VARARGS,
   "V.GetTextRotationArrayName() -> string\nC++: virtual char *GetTextRotationArrayName()\n\nSet/Get the name of the text rotation array.\n"},
  {"GetMTime", PyvtkQtTreeRingLabelMapper_GetMTime, METH_VARARGS,
   "V.GetMTime() -> int\nC++: vtkMTimeType GetMTime() override;\n\nReturn the object's MTime. This is overridden to include the\ntimestamp of its internal class.\n"},
  {"SetRenderer", PyvtkQtTreeRingLabelMapper_SetRenderer, METH_VARARGS,
   "V.SetRenderer(vtkRenderer)\nC++: void SetRenderer(vtkRenderer *ren)\n\n"},
  {"GetRenderer", PyvtkQtTreeRingLabelMapper_GetRenderer, METH_VARARGS,
   "V.GetRenderer() -> vtkRenderer\nC++: vtkRenderer *GetRenderer()\n\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkQtTreeRingLabelMapper_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  "vtkRenderingQtPython.vtkQtTreeRingLabelMapper", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
  nullptr, // tp_print
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkQtTreeRingLabelMapper_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkQtTreeRingLabelMapper_StaticNew()
{
  return vtkQtTreeRingLabelMapper::New();
}

PyObject *PyvtkQtTreeRingLabelMapper_ClassNew()
{
  PyVTKClass_Add(
    &PyvtkQtTreeRingLabelMapper_Type, PyvtkQtTreeRingLabelMapper_Methods,
    "vtkQtTreeRingLabelMapper",
 &PyvtkQtTreeRingLabelMapper_StaticNew);

  PyTypeObject *pytype = &PyvtkQtTreeRingLabelMapper_Type;

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkLabeledDataMapper_ClassNew();

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkQtTreeRingLabelMapper(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkQtTreeRingLabelMapper_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkQtTreeRingLabelMapper", o) != 0)
  {
    Py_DECREF(o);
  }

}

