// python wrapper for vtkBoxLayoutStrategy
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkBoxLayoutStrategy.h"

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkBoxLayoutStrategy(PyObject *); }
extern "C" { VTK_ABI_EXPORT PyObject *PyvtkBoxLayoutStrategy_ClassNew(); }

#ifndef DECLARED_PyvtkTreeMapLayoutStrategy_ClassNew
extern "C" { PyObject *PyvtkTreeMapLayoutStrategy_ClassNew(); }
#define DECLARED_PyvtkTreeMapLayoutStrategy_ClassNew
#endif

static const char *PyvtkBoxLayoutStrategy_Doc =
  "vtkBoxLayoutStrategy - a tree map layout that puts vertices in\nsquare-ish boxes\n\n"
  "Superclass: vtkTreeMapLayoutStrategy\n\n"
  "vtkBoxLayoutStrategy recursively partitions the space for children\n"
  "vertices in a tree-map into square regions (or regions very close to\n"
  "a square).\n\n"
  "@par Thanks: Thanks to Brian Wylie from Sandia National Laboratories\n"
  "for creating this class.\n\n";


static PyObject *
PyvtkBoxLayoutStrategy_IsTypeOf(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkBoxLayoutStrategy::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkBoxLayoutStrategy_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkBoxLayoutStrategy *op = static_cast<vtkBoxLayoutStrategy *>(vp);

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkBoxLayoutStrategy::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkBoxLayoutStrategy_SafeDownCast(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkBoxLayoutStrategy *tempr = vtkBoxLayoutStrategy::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkBoxLayoutStrategy_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkBoxLayoutStrategy *op = static_cast<vtkBoxLayoutStrategy *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkBoxLayoutStrategy *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkBoxLayoutStrategy::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkBoxLayoutStrategy_Layout(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "Layout");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkBoxLayoutStrategy *op = static_cast<vtkBoxLayoutStrategy *>(vp);

  vtkTree *temp0 = nullptr;
  vtkDataArray *temp1 = nullptr;
  vtkDataArray *temp2 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(3) &&
      ap.GetVTKObject(temp0, "vtkTree") &&
      ap.GetVTKObject(temp1, "vtkDataArray") &&
      ap.GetVTKObject(temp2, "vtkDataArray"))
  {
    if (ap.IsBound())
    {
      op->Layout(temp0, temp1, temp2);
    }
    else
    {
      op->vtkBoxLayoutStrategy::Layout(temp0, temp1, temp2);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyMethodDef PyvtkBoxLayoutStrategy_Methods[] = {
  {"IsTypeOf", PyvtkBoxLayoutStrategy_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkBoxLayoutStrategy_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkBoxLayoutStrategy_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkBoxLayoutStrategy\nC++: static vtkBoxLayoutStrategy *SafeDownCast(vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkBoxLayoutStrategy_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkBoxLayoutStrategy\nC++: vtkBoxLayoutStrategy *NewInstance()\n\n"},
  {"Layout", PyvtkBoxLayoutStrategy_Layout, METH_VARARGS,
   "V.Layout(vtkTree, vtkDataArray, vtkDataArray)\nC++: void Layout(vtkTree *inputTree, vtkDataArray *coordsArray,\n    vtkDataArray *sizeArray) override;\n\nPerform the layout of a tree and place the results as 4-tuples in\ncoordsArray (Xmin, Xmax, Ymin, Ymax).\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkBoxLayoutStrategy_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  "vtkInfovisLayoutPython.vtkBoxLayoutStrategy", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
  nullptr, // tp_print
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkBoxLayoutStrategy_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkBoxLayoutStrategy_StaticNew()
{
  return vtkBoxLayoutStrategy::New();
}

PyObject *PyvtkBoxLayoutStrategy_ClassNew()
{
  PyVTKClass_Add(
    &PyvtkBoxLayoutStrategy_Type, PyvtkBoxLayoutStrategy_Methods,
    "vtkBoxLayoutStrategy",
 &PyvtkBoxLayoutStrategy_StaticNew);

  PyTypeObject *pytype = &PyvtkBoxLayoutStrategy_Type;

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkTreeMapLayoutStrategy_ClassNew();

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkBoxLayoutStrategy(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkBoxLayoutStrategy_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkBoxLayoutStrategy", o) != 0)
  {
    Py_DECREF(o);
  }

}

