// python wrapper for vtkTreeAreaView
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkTreeAreaView.h"

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkTreeAreaView(PyObject *); }
extern "C" { VTK_ABI_EXPORT PyObject *PyvtkTreeAreaView_ClassNew(); }

#ifndef DECLARED_PyvtkRenderView_ClassNew
extern "C" { PyObject *PyvtkRenderView_ClassNew(); }
#define DECLARED_PyvtkRenderView_ClassNew
#endif

static const char *PyvtkTreeAreaView_Doc =
  "vtkTreeAreaView - Accepts a graph and a hierarchy - currently a tree\n- and provides a hierarchy-aware display.\n\n"
  "Superclass: vtkRenderView\n\n"
  "Currently, this means displaying the hierarchy using a tree ring\n"
  "layout, then rendering the graph vertices as leaves of the tree with\n"
  "curved graph edges between leaves.\n\n"
  "Takes a graph and a hierarchy (currently a tree) and lays out the\n"
  "graph vertices based on their categorization within the hierarchy.\n\n"
  ".SEE ALSO vtkGraphLayoutView\n\n"
  "@par Thanks: Thanks to Jason Shepherd for implementing this class\n\n";


static PyObject *
PyvtkTreeAreaView_IsTypeOf(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkTreeAreaView::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkTreeAreaView::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SafeDownCast(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkTreeAreaView *tempr = vtkTreeAreaView::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkTreeAreaView *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkTreeAreaView::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetTreeFromInputConnection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetTreeFromInputConnection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  vtkAlgorithmOutput *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkAlgorithmOutput"))
  {
    vtkDataRepresentation *tempr = (ap.IsBound() ?
      op->SetTreeFromInputConnection(temp0) :
      op->vtkTreeAreaView::SetTreeFromInputConnection(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetTreeFromInput(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetTreeFromInput");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  vtkTree *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkTree"))
  {
    vtkDataRepresentation *tempr = (ap.IsBound() ?
      op->SetTreeFromInput(temp0) :
      op->vtkTreeAreaView::SetTreeFromInput(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetGraphFromInputConnection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetGraphFromInputConnection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  vtkAlgorithmOutput *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkAlgorithmOutput"))
  {
    vtkDataRepresentation *tempr = (ap.IsBound() ?
      op->SetGraphFromInputConnection(temp0) :
      op->vtkTreeAreaView::SetGraphFromInputConnection(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetGraphFromInput(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetGraphFromInput");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  vtkGraph *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkGraph"))
  {
    vtkDataRepresentation *tempr = (ap.IsBound() ?
      op->SetGraphFromInput(temp0) :
      op->vtkTreeAreaView::SetGraphFromInput(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetAreaLabelArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetAreaLabelArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetAreaLabelArrayName(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetAreaLabelArrayName(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetAreaLabelArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAreaLabelArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetAreaLabelArrayName() :
      op->vtkTreeAreaView::GetAreaLabelArrayName());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetAreaSizeArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetAreaSizeArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetAreaSizeArrayName(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetAreaSizeArrayName(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetAreaSizeArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAreaSizeArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetAreaSizeArrayName() :
      op->vtkTreeAreaView::GetAreaSizeArrayName());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetLabelPriorityArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetLabelPriorityArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetLabelPriorityArrayName(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetLabelPriorityArrayName(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetLabelPriorityArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetLabelPriorityArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetLabelPriorityArrayName() :
      op->vtkTreeAreaView::GetLabelPriorityArrayName());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetEdgeLabelArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetEdgeLabelArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetEdgeLabelArrayName(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetEdgeLabelArrayName(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetEdgeLabelArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetEdgeLabelArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetEdgeLabelArrayName() :
      op->vtkTreeAreaView::GetEdgeLabelArrayName());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetAreaHoverArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetAreaHoverArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetAreaHoverArrayName(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetAreaHoverArrayName(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetAreaHoverArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAreaHoverArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetAreaHoverArrayName() :
      op->vtkTreeAreaView::GetAreaHoverArrayName());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetAreaLabelVisibility(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetAreaLabelVisibility");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetAreaLabelVisibility(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetAreaLabelVisibility(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetAreaLabelVisibility(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAreaLabelVisibility");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetAreaLabelVisibility() :
      op->vtkTreeAreaView::GetAreaLabelVisibility());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_AreaLabelVisibilityOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "AreaLabelVisibilityOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->AreaLabelVisibilityOn();
    }
    else
    {
      op->vtkTreeAreaView::AreaLabelVisibilityOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_AreaLabelVisibilityOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "AreaLabelVisibilityOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->AreaLabelVisibilityOff();
    }
    else
    {
      op->vtkTreeAreaView::AreaLabelVisibilityOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetEdgeLabelVisibility(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetEdgeLabelVisibility");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetEdgeLabelVisibility(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetEdgeLabelVisibility(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetEdgeLabelVisibility(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetEdgeLabelVisibility");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetEdgeLabelVisibility() :
      op->vtkTreeAreaView::GetEdgeLabelVisibility());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_EdgeLabelVisibilityOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "EdgeLabelVisibilityOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->EdgeLabelVisibilityOn();
    }
    else
    {
      op->vtkTreeAreaView::EdgeLabelVisibilityOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_EdgeLabelVisibilityOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "EdgeLabelVisibilityOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->EdgeLabelVisibilityOff();
    }
    else
    {
      op->vtkTreeAreaView::EdgeLabelVisibilityOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetAreaColorArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetAreaColorArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetAreaColorArrayName(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetAreaColorArrayName(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetAreaColorArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAreaColorArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetAreaColorArrayName() :
      op->vtkTreeAreaView::GetAreaColorArrayName());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetColorAreas(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetColorAreas");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetColorAreas(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetColorAreas(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetColorAreas(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetColorAreas");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetColorAreas() :
      op->vtkTreeAreaView::GetColorAreas());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_ColorAreasOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ColorAreasOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ColorAreasOn();
    }
    else
    {
      op->vtkTreeAreaView::ColorAreasOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_ColorAreasOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ColorAreasOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ColorAreasOff();
    }
    else
    {
      op->vtkTreeAreaView::ColorAreasOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetEdgeColorArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetEdgeColorArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetEdgeColorArrayName(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetEdgeColorArrayName(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetEdgeColorArrayName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetEdgeColorArrayName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetEdgeColorArrayName() :
      op->vtkTreeAreaView::GetEdgeColorArrayName());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetEdgeColorToSplineFraction(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetEdgeColorToSplineFraction");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->SetEdgeColorToSplineFraction();
    }
    else
    {
      op->vtkTreeAreaView::SetEdgeColorToSplineFraction();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetShrinkPercentage(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetShrinkPercentage");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  double temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetShrinkPercentage(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetShrinkPercentage(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetShrinkPercentage(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetShrinkPercentage");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetShrinkPercentage() :
      op->vtkTreeAreaView::GetShrinkPercentage());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetColorEdges(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetColorEdges");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetColorEdges(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetColorEdges(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetColorEdges(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetColorEdges");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetColorEdges() :
      op->vtkTreeAreaView::GetColorEdges());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_ColorEdgesOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ColorEdgesOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ColorEdgesOn();
    }
    else
    {
      op->vtkTreeAreaView::ColorEdgesOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_ColorEdgesOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ColorEdgesOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ColorEdgesOff();
    }
    else
    {
      op->vtkTreeAreaView::ColorEdgesOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetBundlingStrength(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetBundlingStrength");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  double temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetBundlingStrength(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetBundlingStrength(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetBundlingStrength(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetBundlingStrength");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetBundlingStrength() :
      op->vtkTreeAreaView::GetBundlingStrength());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetAreaLabelFontSize(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetAreaLabelFontSize");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetAreaLabelFontSize(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetAreaLabelFontSize(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetAreaLabelFontSize(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAreaLabelFontSize");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetAreaLabelFontSize() :
      op->vtkTreeAreaView::GetAreaLabelFontSize());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetEdgeLabelFontSize(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetEdgeLabelFontSize");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetEdgeLabelFontSize(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetEdgeLabelFontSize(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetEdgeLabelFontSize(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetEdgeLabelFontSize");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetEdgeLabelFontSize() :
      op->vtkTreeAreaView::GetEdgeLabelFontSize());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetLayoutStrategy(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetLayoutStrategy");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  vtkAreaLayoutStrategy *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkAreaLayoutStrategy"))
  {
    if (ap.IsBound())
    {
      op->SetLayoutStrategy(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetLayoutStrategy(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetLayoutStrategy(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetLayoutStrategy");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkAreaLayoutStrategy *tempr = (ap.IsBound() ?
      op->GetLayoutStrategy() :
      op->vtkTreeAreaView::GetLayoutStrategy());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetUseRectangularCoordinates(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetUseRectangularCoordinates");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetUseRectangularCoordinates(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetUseRectangularCoordinates(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetUseRectangularCoordinates(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetUseRectangularCoordinates");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetUseRectangularCoordinates() :
      op->vtkTreeAreaView::GetUseRectangularCoordinates());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_UseRectangularCoordinatesOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "UseRectangularCoordinatesOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->UseRectangularCoordinatesOn();
    }
    else
    {
      op->vtkTreeAreaView::UseRectangularCoordinatesOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_UseRectangularCoordinatesOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "UseRectangularCoordinatesOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->UseRectangularCoordinatesOff();
    }
    else
    {
      op->vtkTreeAreaView::UseRectangularCoordinatesOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_SetEdgeScalarBarVisibility(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetEdgeScalarBarVisibility");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetEdgeScalarBarVisibility(temp0);
    }
    else
    {
      op->vtkTreeAreaView::SetEdgeScalarBarVisibility(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkTreeAreaView_GetEdgeScalarBarVisibility(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetEdgeScalarBarVisibility");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTreeAreaView *op = static_cast<vtkTreeAreaView *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetEdgeScalarBarVisibility() :
      op->vtkTreeAreaView::GetEdgeScalarBarVisibility());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyMethodDef PyvtkTreeAreaView_Methods[] = {
  {"IsTypeOf", PyvtkTreeAreaView_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkTreeAreaView_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkTreeAreaView_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkTreeAreaView\nC++: static vtkTreeAreaView *SafeDownCast(vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkTreeAreaView_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkTreeAreaView\nC++: vtkTreeAreaView *NewInstance()\n\n"},
  {"SetTreeFromInputConnection", PyvtkTreeAreaView_SetTreeFromInputConnection, METH_VARARGS,
   "V.SetTreeFromInputConnection(vtkAlgorithmOutput)\n    -> vtkDataRepresentation\nC++: vtkDataRepresentation *SetTreeFromInputConnection(\n    vtkAlgorithmOutput *conn)\n\nSet the tree and graph representations to the appropriate input\nports.\n"},
  {"SetTreeFromInput", PyvtkTreeAreaView_SetTreeFromInput, METH_VARARGS,
   "V.SetTreeFromInput(vtkTree) -> vtkDataRepresentation\nC++: vtkDataRepresentation *SetTreeFromInput(vtkTree *input)\n\nSet the tree and graph representations to the appropriate input\nports.\n"},
  {"SetGraphFromInputConnection", PyvtkTreeAreaView_SetGraphFromInputConnection, METH_VARARGS,
   "V.SetGraphFromInputConnection(vtkAlgorithmOutput)\n    -> vtkDataRepresentation\nC++: vtkDataRepresentation *SetGraphFromInputConnection(\n    vtkAlgorithmOutput *conn)\n\nSet the tree and graph representations to the appropriate input\nports.\n"},
  {"SetGraphFromInput", PyvtkTreeAreaView_SetGraphFromInput, METH_VARARGS,
   "V.SetGraphFromInput(vtkGraph) -> vtkDataRepresentation\nC++: vtkDataRepresentation *SetGraphFromInput(vtkGraph *input)\n\nSet the tree and graph representations to the appropriate input\nports.\n"},
  {"SetAreaLabelArrayName", PyvtkTreeAreaView_SetAreaLabelArrayName, METH_VARARGS,
   "V.SetAreaLabelArrayName(string)\nC++: void SetAreaLabelArrayName(const char *name)\n\nThe array to use for area labeling.  Default is \"label\".\n"},
  {"GetAreaLabelArrayName", PyvtkTreeAreaView_GetAreaLabelArrayName, METH_VARARGS,
   "V.GetAreaLabelArrayName() -> string\nC++: const char *GetAreaLabelArrayName()\n\nThe array to use for area labeling.  Default is \"label\".\n"},
  {"SetAreaSizeArrayName", PyvtkTreeAreaView_SetAreaSizeArrayName, METH_VARARGS,
   "V.SetAreaSizeArrayName(string)\nC++: void SetAreaSizeArrayName(const char *name)\n\nThe array to use for area sizes. Default is \"size\".\n"},
  {"GetAreaSizeArrayName", PyvtkTreeAreaView_GetAreaSizeArrayName, METH_VARARGS,
   "V.GetAreaSizeArrayName() -> string\nC++: const char *GetAreaSizeArrayName()\n\nThe array to use for area sizes. Default is \"size\".\n"},
  {"SetLabelPriorityArrayName", PyvtkTreeAreaView_SetLabelPriorityArrayName, METH_VARARGS,
   "V.SetLabelPriorityArrayName(string)\nC++: void SetLabelPriorityArrayName(const char *name)\n\nThe array to use for area labeling priority. Default is\n\"GraphVertexDegree\".\n"},
  {"GetLabelPriorityArrayName", PyvtkTreeAreaView_GetLabelPriorityArrayName, METH_VARARGS,
   "V.GetLabelPriorityArrayName() -> string\nC++: const char *GetLabelPriorityArrayName()\n\nThe array to use for area labeling priority. Default is\n\"GraphVertexDegree\".\n"},
  {"SetEdgeLabelArrayName", PyvtkTreeAreaView_SetEdgeLabelArrayName, METH_VARARGS,
   "V.SetEdgeLabelArrayName(string)\nC++: void SetEdgeLabelArrayName(const char *name)\n\nThe array to use for edge labeling.  Default is \"label\".\n"},
  {"GetEdgeLabelArrayName", PyvtkTreeAreaView_GetEdgeLabelArrayName, METH_VARARGS,
   "V.GetEdgeLabelArrayName() -> string\nC++: const char *GetEdgeLabelArrayName()\n\nThe array to use for edge labeling.  Default is \"label\".\n"},
  {"SetAreaHoverArrayName", PyvtkTreeAreaView_SetAreaHoverArrayName, METH_VARARGS,
   "V.SetAreaHoverArrayName(string)\nC++: void SetAreaHoverArrayName(const char *name)\n\nThe name of the array whose value appears when the mouse hovers\nover a rectangle in the treemap. This must be a string array.\n"},
  {"GetAreaHoverArrayName", PyvtkTreeAreaView_GetAreaHoverArrayName, METH_VARARGS,
   "V.GetAreaHoverArrayName() -> string\nC++: const char *GetAreaHoverArrayName()\n\nThe name of the array whose value appears when the mouse hovers\nover a rectangle in the treemap. This must be a string array.\n"},
  {"SetAreaLabelVisibility", PyvtkTreeAreaView_SetAreaLabelVisibility, METH_VARARGS,
   "V.SetAreaLabelVisibility(bool)\nC++: void SetAreaLabelVisibility(bool vis)\n\nWhether to show area labels.  Default is off.\n"},
  {"GetAreaLabelVisibility", PyvtkTreeAreaView_GetAreaLabelVisibility, METH_VARARGS,
   "V.GetAreaLabelVisibility() -> bool\nC++: bool GetAreaLabelVisibility()\n\nWhether to show area labels.  Default is off.\n"},
  {"AreaLabelVisibilityOn", PyvtkTreeAreaView_AreaLabelVisibilityOn, METH_VARARGS,
   "V.AreaLabelVisibilityOn()\nC++: virtual void AreaLabelVisibilityOn()\n\nWhether to show area labels.  Default is off.\n"},
  {"AreaLabelVisibilityOff", PyvtkTreeAreaView_AreaLabelVisibilityOff, METH_VARARGS,
   "V.AreaLabelVisibilityOff()\nC++: virtual void AreaLabelVisibilityOff()\n\nWhether to show area labels.  Default is off.\n"},
  {"SetEdgeLabelVisibility", PyvtkTreeAreaView_SetEdgeLabelVisibility, METH_VARARGS,
   "V.SetEdgeLabelVisibility(bool)\nC++: void SetEdgeLabelVisibility(bool vis)\n\nWhether to show edge labels.  Default is off.\n"},
  {"GetEdgeLabelVisibility", PyvtkTreeAreaView_GetEdgeLabelVisibility, METH_VARARGS,
   "V.GetEdgeLabelVisibility() -> bool\nC++: bool GetEdgeLabelVisibility()\n\nWhether to show edge labels.  Default is off.\n"},
  {"EdgeLabelVisibilityOn", PyvtkTreeAreaView_EdgeLabelVisibilityOn, METH_VARARGS,
   "V.EdgeLabelVisibilityOn()\nC++: virtual void EdgeLabelVisibilityOn()\n\nWhether to show edge labels.  Default is off.\n"},
  {"EdgeLabelVisibilityOff", PyvtkTreeAreaView_EdgeLabelVisibilityOff, METH_VARARGS,
   "V.EdgeLabelVisibilityOff()\nC++: virtual void EdgeLabelVisibilityOff()\n\nWhether to show edge labels.  Default is off.\n"},
  {"SetAreaColorArrayName", PyvtkTreeAreaView_SetAreaColorArrayName, METH_VARARGS,
   "V.SetAreaColorArrayName(string)\nC++: void SetAreaColorArrayName(const char *name)\n\nThe array to use for coloring vertices.  Default is \"color\".\n"},
  {"GetAreaColorArrayName", PyvtkTreeAreaView_GetAreaColorArrayName, METH_VARARGS,
   "V.GetAreaColorArrayName() -> string\nC++: const char *GetAreaColorArrayName()\n\nThe array to use for coloring vertices.  Default is \"color\".\n"},
  {"SetColorAreas", PyvtkTreeAreaView_SetColorAreas, METH_VARARGS,
   "V.SetColorAreas(bool)\nC++: void SetColorAreas(bool vis)\n\nWhether to color vertices.  Default is off.\n"},
  {"GetColorAreas", PyvtkTreeAreaView_GetColorAreas, METH_VARARGS,
   "V.GetColorAreas() -> bool\nC++: bool GetColorAreas()\n\nWhether to color vertices.  Default is off.\n"},
  {"ColorAreasOn", PyvtkTreeAreaView_ColorAreasOn, METH_VARARGS,
   "V.ColorAreasOn()\nC++: virtual void ColorAreasOn()\n\nWhether to color vertices.  Default is off.\n"},
  {"ColorAreasOff", PyvtkTreeAreaView_ColorAreasOff, METH_VARARGS,
   "V.ColorAreasOff()\nC++: virtual void ColorAreasOff()\n\nWhether to color vertices.  Default is off.\n"},
  {"SetEdgeColorArrayName", PyvtkTreeAreaView_SetEdgeColorArrayName, METH_VARARGS,
   "V.SetEdgeColorArrayName(string)\nC++: void SetEdgeColorArrayName(const char *name)\n\nThe array to use for coloring edges.  Default is \"color\".\n"},
  {"GetEdgeColorArrayName", PyvtkTreeAreaView_GetEdgeColorArrayName, METH_VARARGS,
   "V.GetEdgeColorArrayName() -> string\nC++: const char *GetEdgeColorArrayName()\n\nThe array to use for coloring edges.  Default is \"color\".\n"},
  {"SetEdgeColorToSplineFraction", PyvtkTreeAreaView_SetEdgeColorToSplineFraction, METH_VARARGS,
   "V.SetEdgeColorToSplineFraction()\nC++: void SetEdgeColorToSplineFraction()\n\nSet the color to be the spline fraction\n"},
  {"SetShrinkPercentage", PyvtkTreeAreaView_SetShrinkPercentage, METH_VARARGS,
   "V.SetShrinkPercentage(float)\nC++: void SetShrinkPercentage(double value)\n\nSet the region shrink percentage between 0.0 and 1.0.\n"},
  {"GetShrinkPercentage", PyvtkTreeAreaView_GetShrinkPercentage, METH_VARARGS,
   "V.GetShrinkPercentage() -> float\nC++: double GetShrinkPercentage()\n\nSet the region shrink percentage between 0.0 and 1.0.\n"},
  {"SetColorEdges", PyvtkTreeAreaView_SetColorEdges, METH_VARARGS,
   "V.SetColorEdges(bool)\nC++: void SetColorEdges(bool vis)\n\nWhether to color edges.  Default is off.\n"},
  {"GetColorEdges", PyvtkTreeAreaView_GetColorEdges, METH_VARARGS,
   "V.GetColorEdges() -> bool\nC++: bool GetColorEdges()\n\nWhether to color edges.  Default is off.\n"},
  {"ColorEdgesOn", PyvtkTreeAreaView_ColorEdgesOn, METH_VARARGS,
   "V.ColorEdgesOn()\nC++: virtual void ColorEdgesOn()\n\nWhether to color edges.  Default is off.\n"},
  {"ColorEdgesOff", PyvtkTreeAreaView_ColorEdgesOff, METH_VARARGS,
   "V.ColorEdgesOff()\nC++: virtual void ColorEdgesOff()\n\nWhether to color edges.  Default is off.\n"},
  {"SetBundlingStrength", PyvtkTreeAreaView_SetBundlingStrength, METH_VARARGS,
   "V.SetBundlingStrength(float)\nC++: void SetBundlingStrength(double strength)\n\nSet the bundling strength.\n"},
  {"GetBundlingStrength", PyvtkTreeAreaView_GetBundlingStrength, METH_VARARGS,
   "V.GetBundlingStrength() -> float\nC++: double GetBundlingStrength()\n\nSet the bundling strength.\n"},
  {"SetAreaLabelFontSize", PyvtkTreeAreaView_SetAreaLabelFontSize, METH_VARARGS,
   "V.SetAreaLabelFontSize(int)\nC++: virtual void SetAreaLabelFontSize(const int size)\n\nThe size of the font used for area labeling\n"},
  {"GetAreaLabelFontSize", PyvtkTreeAreaView_GetAreaLabelFontSize, METH_VARARGS,
   "V.GetAreaLabelFontSize() -> int\nC++: virtual int GetAreaLabelFontSize()\n\nThe size of the font used for area labeling\n"},
  {"SetEdgeLabelFontSize", PyvtkTreeAreaView_SetEdgeLabelFontSize, METH_VARARGS,
   "V.SetEdgeLabelFontSize(int)\nC++: virtual void SetEdgeLabelFontSize(const int size)\n\nThe size of the font used for edge labeling\n"},
  {"GetEdgeLabelFontSize", PyvtkTreeAreaView_GetEdgeLabelFontSize, METH_VARARGS,
   "V.GetEdgeLabelFontSize() -> int\nC++: virtual int GetEdgeLabelFontSize()\n\nThe size of the font used for edge labeling\n"},
  {"SetLayoutStrategy", PyvtkTreeAreaView_SetLayoutStrategy, METH_VARARGS,
   "V.SetLayoutStrategy(vtkAreaLayoutStrategy)\nC++: virtual void SetLayoutStrategy(\n    vtkAreaLayoutStrategy *strategy)\n\nThe layout strategy for producing spatial regions for the tree.\n"},
  {"GetLayoutStrategy", PyvtkTreeAreaView_GetLayoutStrategy, METH_VARARGS,
   "V.GetLayoutStrategy() -> vtkAreaLayoutStrategy\nC++: virtual vtkAreaLayoutStrategy *GetLayoutStrategy()\n\nThe layout strategy for producing spatial regions for the tree.\n"},
  {"SetUseRectangularCoordinates", PyvtkTreeAreaView_SetUseRectangularCoordinates, METH_VARARGS,
   "V.SetUseRectangularCoordinates(bool)\nC++: virtual void SetUseRectangularCoordinates(bool rect)\n\nWhether the area represents radial or rectangular coordinates.\n"},
  {"GetUseRectangularCoordinates", PyvtkTreeAreaView_GetUseRectangularCoordinates, METH_VARARGS,
   "V.GetUseRectangularCoordinates() -> bool\nC++: virtual bool GetUseRectangularCoordinates()\n\nWhether the area represents radial or rectangular coordinates.\n"},
  {"UseRectangularCoordinatesOn", PyvtkTreeAreaView_UseRectangularCoordinatesOn, METH_VARARGS,
   "V.UseRectangularCoordinatesOn()\nC++: virtual void UseRectangularCoordinatesOn()\n\nWhether the area represents radial or rectangular coordinates.\n"},
  {"UseRectangularCoordinatesOff", PyvtkTreeAreaView_UseRectangularCoordinatesOff, METH_VARARGS,
   "V.UseRectangularCoordinatesOff()\nC++: virtual void UseRectangularCoordinatesOff()\n\nWhether the area represents radial or rectangular coordinates.\n"},
  {"SetEdgeScalarBarVisibility", PyvtkTreeAreaView_SetEdgeScalarBarVisibility, METH_VARARGS,
   "V.SetEdgeScalarBarVisibility(bool)\nC++: virtual void SetEdgeScalarBarVisibility(bool b)\n\nVisibility of scalar bar actor for edges.\n"},
  {"GetEdgeScalarBarVisibility", PyvtkTreeAreaView_GetEdgeScalarBarVisibility, METH_VARARGS,
   "V.GetEdgeScalarBarVisibility() -> bool\nC++: virtual bool GetEdgeScalarBarVisibility()\n\nVisibility of scalar bar actor for edges.\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkTreeAreaView_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  "vtkViewsInfovisPython.vtkTreeAreaView", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
  nullptr, // tp_print
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkTreeAreaView_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkTreeAreaView_StaticNew()
{
  return vtkTreeAreaView::New();
}

PyObject *PyvtkTreeAreaView_ClassNew()
{
  PyVTKClass_Add(
    &PyvtkTreeAreaView_Type, PyvtkTreeAreaView_Methods,
    "vtkTreeAreaView",
 &PyvtkTreeAreaView_StaticNew);

  PyTypeObject *pytype = &PyvtkTreeAreaView_Type;

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkRenderView_ClassNew();

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkTreeAreaView(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkTreeAreaView_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkTreeAreaView", o) != 0)
  {
    Py_DECREF(o);
  }

}

